import { css, LitElement, html } from 'lit-element';

const BsBadgeCss = css`
    :host([pill]) {
        --badge-pd-right: var(--badge-pill-pd-top, 0.6em);
        --badge-pd-left: var(--badge-pill-pd-left, 0.6em);
        --badge-bd-radius: var(--badge-pill-bd-radius, 10rem);
    }

    :host([context="primary"]) {
        --badge-color: var(--badge-primary-color, #fff);
        --badge-bg-color: var(--badge-primary-bg-color, #007bff);
    }

    :host([context="secondary"]) {
        --badge-color: var(--badge-secondary-color, #fff);
        --badge-bg-color: var(--badge-secondary-bg-color, #6c757d);
    }

    :host([context="success"]) {
        --badge-color: var(--badge-success-color, #fff);
        --badge-bg-color: var(--badge-success-bg-color, #28a745);
    }

    :host([context="info"]) {
        --badge-color: var(--badge-info-color, #fff);
        --badge-bg-color: var(--badge-info-bg-color, #17a2b8);
    }

    :host([context="warning"]) {
        --badge-color: var(--badge-warning-color, #212529);
        --badge-bg-color: var(--badge-warning-bg-color, #ffc107);
    }

    :host([context="danger"]) {
        --badge-color: var(--badge-danger-color, #fff);
        --badge-bg-color: var(--badge-danger-bg-color, #dc3545);
    }

    :host([context="light"]) {
        --badge-color: var(--badge-light-color, #212529);
        --badge-bg-color: var(--badge-light-bg-color, #f8f9fa);
    }

    :host([context="dark"]) {
        --badge-color: var(--badge-dark-color, #fff);
        --badge-bg-color: var(--badge-dark-bg-color, #343a40);
    }

    :host {
        display: inline-block;
        padding-top: var(--badge-pd-top, 0.25em);
        padding-bottom: var(--badge-pd-bottom, 0.25em);
        padding-left: var(--badge-pd-left, 0.4em);
        padding-right: var(--badge-pd-right, 0.4em);
        font-size: var(--badge-font-size, 75%);
        font-weight: var(--badge-font-wg, 700);
        line-height: var(--badge-line-hg, 1);
        text-align: var(--badge-text-align, center);
        white-space: nowrap;
        vertical-align: baseline;
        border-radius: var(--badge-bd-radius, 0.25rem);
        color: var(--badge-color);
        background-color: var(--badge-bg-color);
    }

    @media (prefers-reduced-motion: reduce) {
        :host {
            transition: none;
        }
    }

    :host:empty {
        display: none;
    }
`;

const BsBadgeRebootCss = css`
    *,
    *::before,
    *::after {
        box-sizing: border-box;
    }

    :host,
    :host::before,
    :host::after {
        box-sizing: border-box;
    }
`;

/**
 * Badge Component
 *
 * @element bs-badge
 *
 * @attribute pill - Indicates if badge should be displayed as a pill
 * @attribute {primary|secondary|success|info|warning|danger|light|dark} context -
 * Indicates the styling context to use
 *
 * @slot Slot for badge content
 *
 * @cssproperty --badge-color - Text color, default: user agent
 * @cssproperty --badge-bg-color - Background color, default: user agent
 * @cssproperty --badge-pd-top - Padding top, default: 0.25em
 * @cssproperty --badge-pd-bottom - Padding bottom, default: 0.25em
 * @cssproperty --badge-pd-left - Padding left, default: 0.4em
 * @cssproperty --badge-pd-right - Padding right, default: 0.4em
 * @cssproperty --badge-font-size - The badge font size, default: 75%
 * @cssproperty --badge-font-wg - Font weight, default: 700
 * @cssproperty --badge-line-hg - Line height, default: 1
 * @cssproperty --badge-text-align - Text align, default: center
 * @cssproperty --badge-bd-radius - Border radius, default: 0.25rem
 * @cssproperty --badge-pill-pd-top - Pill padding top, default: 0.6em
 * @cssproperty --badge-pill-pd-left - Pill padding left, default: 0.6em
 * @cssproperty --badge-pill-bd-radius - Pill border radius, default: 10rem
 * @cssproperty --badge-primary-color - Primary context text color, default: #fff
 * @cssproperty --badge-primary-bg-color - Primary context background color, default: #007bff
 * @cssproperty --badge-secondary-color - Secondary context text color, default: #fff
 * @cssproperty --badge-secondary-bg-color - Secondary context background color, default: #6c757d
 * @cssproperty --badge-success-color - Success context text color, default: #fff
 * @cssproperty --badge-success-bg-color - Success context background color, default: #28a745
 * @cssproperty --badge-info-color - Info context text color, default: #fff
 * @cssproperty --badge-info-bg-color - Info context background color, default: #17a2b8
 * @cssproperty --badge-warning-color - Warning context text color, default: #212529
 * @cssproperty --badge-warning-bg-color - Warning context background color, default: #ffc107
 * @cssproperty --badge-danger-color - Danger context text color, default: #fff
 * @cssproperty --badge-danger-bg-color - Danger context background color, default: #dc3545
 * @cssproperty --badge-light-color - Light context text color, default: #212529
 * @cssproperty --badge-light-bg-color - Light context background color, default: #f8f9fa
 * @cssproperty --badge-dark-color - Dark context text color, default: #fff
 * @cssproperty --badge-dark-bg-color - Dark context background color, default: #343a40
 */

class BsBadge extends LitElement {
  static get styles() {
    return [BsBadgeRebootCss, BsBadgeCss];
  }

  render() {
    return html`
            <slot></slot>
        `;
  }

}
if (!window.customElements.get("bs-badge")) window.customElements.define("bs-badge", BsBadge);

const BsBadgeLinkCss = css`
    :host([pill]) {
        --badge-link-pd-right: var(--badge-link-pill-pd-top, 0.6em);
        --badge-link-pd-left: var(--badge-link-pill-pd-left, 0.6em);
        --badge-link-bd-radius: var(--badge-link-pill-bd-radius, 10rem);
    }

    :host([context="primary"]) a {
        --badge-link-color: var(--badge-link-primary-color, #fff);
        --badge-link-bg-color: var(--badge-link-primary-bg-color, #007bff);
        --badge-link-text-decoration: var(
            --badge-link-primary-text-decoration,
            none
        );
    }

    :host([context="primary"]) a:hover {
        --badge-link-color: var(--badge-link-primary-hover-color, #fff);
        --badge-link-bg-color: var(
            --badge-link-primary-hover-bg-color,
            #0062cc
        );
    }

    :host([context="primary"]) a:focus :host([context="primary"]) a.focus {
        --badge-link-color: var(--badge-link-primary-focus-color, #fff);
        --badge-link-bg-color: var(
            --badge-link-primary-focus-bg-color,
            #0062cc
        );
        --badge-link-outline: var(--badge-link-primary-link-outline, 0);
        --badge-link-box-shadow: var(
            --badge-link-primary-link-box-shadow,
            0 0 0 0.2rem rgba(0, 123, 255, 0.5)
        );
    }

    :host([context="secondary"]) a {
        --badge-link-color: var(--badge-link-secondary-color, #fff);
        --badge-link-bg-color: var(--badge-link-secondary-bg-color, #6c757d);
        --badge-link-text-decoration: var(
            --badge-link-secondary-text-decoration,
            none
        );
    }

    :host([context="secondary"]) a:hover {
        --badge-link-color: var(--badge-link-secondary-hover-color, #fff);
        --badge-link-bg-color: var(
            --badge-link-secondary-hover-bg-color,
            #545b62
        );
    }

    :host([context="secondary"]) a:focus :host([context="secondary"]) a.focus {
        --badge-link-color: var(--badge-link-secondary-focus-color, #fff);
        --badge-link-bg-color: var(
            --badge-link-secondary-focus-bg-color,
            #545b62
        );
        --badge-link-outline: var(--badge-link-secondary-link-outline, 0);
        --badge-link-box-shadow: var(
            --badge-link-secondary-link-box-shadow,
            0 0 0 0.2rem rgba(108, 117, 125, 0.5)
        );
    }

    :host([context="success"]) a {
        --badge-link-color: var(--badge-link-success-color, #fff);
        --badge-link-bg-color: var(--badge-link-success-bg-color, #28a745);
        --badge-link-text-decoration: var(
            --badge-link-success-text-decoration,
            none
        );
    }

    :host([context="success"]) a:hover {
        --badge-link-color: var(--badge-link-success-hover-color, #fff);
        --badge-link-bg-color: var(
            --badge-link-success-hover-bg-color,
            #1e7e34
        );
    }

    :host([context="success"]) a:focus :host([context="success"]) a.focus {
        --badge-link-color: var(--badge-link-success-focus-color, #fff);
        --badge-link-bg-color: var(
            --badge-link-success-focus-bg-color,
            #1e7e34
        );
        --badge-link-outline: var(--badge-link-success-link-outline, 0);
        --badge-link-box-shadow: var(
            --badge-link-success-link-box-shadow,
            0 0 0 0.2rem rgba(40, 167, 69, 0.5)
        );
    }

    :host([context="info"]) a {
        --badge-link-color: var(--badge-link-info-color, #fff);
        --badge-link-bg-color: var(--badge-link-info-bg-color, #17a2b8);
        --badge-link-text-decoration: var(
            --badge-link-info-text-decoration,
            none
        );
    }

    :host([context="info"]) a:hover {
        --badge-link-color: var(--badge-link-info-hover-color, #fff);
        --badge-link-bg-color: var(--badge-link-info-hover-bg-color, #117a8b);
    }

    :host([context="info"]) a:focus :host([context="info"]) a.focus {
        --badge-link-color: var(--badge-link-info-focus-color, #fff);
        --badge-link-bg-color: var(--badge-link-info-focus-bg-color, #117a8b);
        --badge-link-outline: var(--badge-link-info-link-outline, 0);
        --badge-link-box-shadow: var(
            --badge-link-info-link-box-shadow,
            0 0 0 0.2rem rgba(23, 162, 184, 0.5)
        );
    }

    :host([context="warning"]) a {
        --badge-link-color: var(--badge-link-warning-color, #212529);
        --badge-link-bg-color: var(--badge-link-warning-bg-color, #ffc107);
        --badge-link-text-decoration: var(
            --badge-link-warning-text-decoration,
            none
        );
    }

    :host([context="warning"]) a:hover {
        --badge-link-color: var(--badge-link-warning-hover-color, #212529);
        --badge-link-bg-color: var(
            --badge-link-warning-hover-bg-color,
            #d39e00
        );
    }

    :host([context="warning"]) a:focus :host([context="warning"]) a.focus {
        --badge-link-color: var(--badge-link-warning-focus-color, #212529);
        --badge-link-bg-color: var(
            --badge-link-warning-focus-bg-color,
            #d39e00
        );
        --badge-link-outline: var(--badge-link-warning-link-outline, 0);
        --badge-link-box-shadow: var(
            --badge-link-warning-link-box-shadow,
            0 0 0 0.2rem rgba(255, 193, 7, 0.5)
        );
    }

    :host([context="danger"]) a {
        --badge-link-color: var(--badge-link-danger-color, #fff);
        --badge-link-bg-color: var(--badge-link-danger-bg-color, #dc3545);
        --badge-link-text-decoration: var(
            --badge-link-danger-text-decoration,
            none
        );
    }

    :host([context="danger"]) a:hover {
        --badge-link-color: var(--badge-link-danger-hover-color, #fff);
        --badge-link-bg-color: var(--badge-link-danger-hover-bg-color, #bd2130);
    }

    :host([context="danger"]) a:focus :host([context="danger"]) a.focus {
        --badge-link-color: var(--badge-link-danger-focus-color, #fff);
        --badge-link-bg-color: var(--badge-link-danger-focus-bg-color, #bd2130);
        --badge-link-outline: var(--badge-link-danger-link-outline, 0);
        --badge-link-box-shadow: var(
            --badge-link-danger-link-box-shadow,
            0 0 0 0.2rem rgba(220, 53, 69, 0.5)
        );
    }

    :host([context="light"]) a {
        --badge-link-color: var(--badge-link-light-color, #212529);
        --badge-link-bg-color: var(--badge-link-light-bg-color, #f8f9fa);
        --badge-link-text-decoration: var(
            --badge-link-light-text-decoration,
            none
        );
    }

    :host([context="light"]) a:hover {
        --badge-link-color: var(--badge-link-light-hover-color, #212529);
        --badge-link-bg-color: var(--badge-link-light-hover-bg-color, #dae0e5);
    }

    :host([context="light"]) a:focus :host([context="light"]) a.focus {
        --badge-link-color: var(--badge-link-light-focus-color, #212529);
        --badge-link-bg-color: var(--badge-link-light-focus-bg-color, #dae0e5);
        --badge-link-outline: var(--badge-link-light-link-outline, 0);
        --badge-link-box-shadow: var(
            --badge-link-light-link-box-shadow,
            0 0 0 0.2rem rgba(248, 249, 250, 0.5)
        );
    }

    :host([context="dark"]) a {
        --badge-link-color: var(--badge-dark-color, #fff);
        --badge-link-bg-color: var(--badge-dark-bg-color, #343a40);
        --badge-link-text-decoration: var(
            --badge-link-dark-text-decoration,
            none
        );
    }

    :host([context="dark"]) a:hover {
        --badge-link-color: var(--badge-link-dark-hover-color, #fff);
        --badge-link-bg-color: var(--badge-link-dark-hover-bg-color, #1d2124);
    }

    :host([context="dark"]) a:focus :host([context="dark"]) a.focus {
        --badge-link-color: var(--badge-link-dark-focus-color, #212529);
        --badge-link-bg-color: var(--badge-link-dark-focus-bg-color, #dae0e5);
        --badge-link-outline: var(--badge-link-dark-link-outline, 0);
        --badge-link-box-shadow: var(
            --badge-link-dark-link-box-shadow,
            0 0 0 0.2rem rgba(52, 58, 64, 0.5)
        );
    }

    a {
        display: inline-block;
        padding-top: var(--badge-link-pd-top, 0.25em);
        padding-bottom: var(--badge-link-pd-bottom, 0.25em);
        padding-left: var(--badge-link-pd-left, 0.4em);
        padding-right: var(--badge-link-pd-right, 0.4em);
        font-size: var(--badge-link-font-size, 75%);
        font-weight: var(--badge-link-font-wg, 700);
        line-height: var(--badge-link-line-hg, 1);
        text-align: var(--badge-link-text-align, center);
        white-space: nowrap;
        vertical-align: baseline;
        border-radius: var(--badge-link-bd-radius, 0.25rem);
        color: var(--badge-link-color, #007bff);
        background-color: var(--badge-link-bg-color, transparent);
        outline: var(--badge-link-outline);
        box-shadow: var(--badge-link-box-shadow);
        text-decoration: var(--badge-link-text-decoration, none);
        -webkit-text-decoration-skip: objects;
    }

    a:hover {
        text-decoration: var(--badge-link-hover-text-decoration, none);
    }

    a:focus {
        text-decoration: var(--badge-link-focus-text-decoration, none);
    }

    @media (prefers-reduced-motion: reduce) {
        a {
            transition: none;
        }
    }

    a:empty {
        display: none;
    }

    a:not([href]):not([tabindex]) {
        color: inherit;
        text-decoration: none;
    }

    a:not([href]):not([tabindex]):hover,
    a:not([href]):not([tabindex]):focus {
        color: inherit;
        text-decoration: none;
    }

    a:not([href]):not([tabindex]):focus {
        outline: 0;
    }
`;

/**
 * Badge Link Component
 *
 * @element bs-badge-link
 *
 * @attribute href - The hyper link to point to
 * @attribute target - The context target
 * @attribute pill - Indicates if badge should be displayed as a pill
 * @attribute {primary|secondary|success|info|warning|danger|light|dark} context -
 * Indicates the styling context to use
 *
 * @property {String} href - The hyper link to point, default: ''
 * @property {String} target - The context target. default: _self
 *
 * @slot Slot for badge link content
 *
 * @cssproperty --badge-link-color - Text color, default: #007bff
 * @cssproperty --badge-link-bg-color - Background color, default: transparent
 * @cssproperty --badge-link-pd-top - Padding top, default: 0.25em
 * @cssproperty --badge-link-pd-bottom - Padding bottom, default: 0.25em
 * @cssproperty --badge-link-pd-left - Padding left, default: 0.4em
 * @cssproperty --badge-link-pd-right- Padding right, default: 0.4em
 * @cssproperty --badge-link-font-size - Font size, default: 75%
 * @cssproperty --badge-link-font-wg - Font weight, default: 700
 * @cssproperty --badge-link-line-hg - Line height, default: 1
 * @cssproperty --badge-link-text-align - Text align, default: center
 * @cssproperty --badge-link-bd-radius - Border radius, default: 0.25rem
 * @cssproperty --badge-link-pill-pd-top - Pill padding right, default: 0.6em
 * @cssproperty --badge-link-pill-pd-left - Pill padding left, default: 0.6em
 * @cssproperty --badge-link-pill-bd-radius - Pill border radius, default: 10rem
 * @cssproperty --badge-link-primary-color - Primary context text color, default: #fff
 * @cssproperty --badge-link-primary-bg-color - Primary context background color, default: #007bff
 * @cssproperty --badge-link-primary-text-decoration - Primary context text decoration, default: none
 * @cssproperty --badge-link-primary-hover-color - Primary context hover text color, default: #fff
 * @cssproperty --badge-link-primary-hover-bg-color - Primary context hover background color, default: #0062cc
 * @cssproperty --badge-link-primary-focus-color - Primary context focus text color, default: #fff
 * @cssproperty --badge-link-primary-focus-bg-color - Primary context focus background color, default: #0062cc
 * @cssproperty --badge-link-primary-link-outline - Primary context link outline, default: 0
 * @cssproperty --badge-link-primary-link-box-shadow - Primary context link box shadow, default: 0 0 0 0.2rem rgba(0, 123, 255, 0.5)
 * @cssproperty --badge-link-secondary-color - Secondary context text color, default: #fff
 * @cssproperty --badge-link-secondary-bg-color - Secondary context background color, default: #6c757d
 * @cssproperty --badge-link-secondary-text-decoration - Secondary context text decoration, default: none
 * @cssproperty --badge-link-secondary-hover-color - Secondary context hover text color, default: #fff
 * @cssproperty --badge-link-secondary-hover-bg-color - Secondary context hover background color, default: #545b62
 * @cssproperty --badge-link-secondary-focus-color - Secondary context focus text color, default: #fff
 * @cssproperty --badge-link-secondary-focus-bg-color - Secondary context focus background color, default: #545b62
 * @cssproperty --badge-link-secondary-link-outline - Secondary context link outline, default: 0
 * @cssproperty --badge-link-secondary-link-box-shadow - Secondary context link box shadow, default: 0 0 0 0.2rem rgba(108, 117, 125, 0.5)
 * @cssproperty --badge-link-success-color - Success context text color, default: #fff
 * @cssproperty --badge-link-success-bg-color - Success context background color, default: #28a745
 * @cssproperty --badge-link-success-text-decoration - Success context text decoration, default: none
 * @cssproperty --badge-link-success-hover-color - Success context hover text color, default: #fff
 * @cssproperty --badge-link-success-hover-bg-color - Success context hover background color, default: #1e7e34
 * @cssproperty --badge-link-success-focus-color - Success context focus text color, default: #fff
 * @cssproperty --badge-link-success-focus-bg-color - Success context focus background color, default: #1e7e34
 * @cssproperty --badge-link-success-link-outline - Success context link outline, default: 0
 * @cssproperty --badge-link-success-link-box-shadow - Success context link box shadow, default: 0 0 0 0.2rem rgba(40, 167, 69, 0.5)
 * @cssproperty --badge-link-info-color - Info context text color, default: #fff
 * @cssproperty --badge-link-info-bg-color - Info context background color, default: #17a2b8
 * @cssproperty --badge-link-info-text-decoration - Info context text decoration, default: none
 * @cssproperty --badge-link-info-hover-color - Info context hover text color, default: #fff
 * @cssproperty --badge-link-info-hover-bg-color - Info context hover background color, default: #117a8b
 * @cssproperty --badge-link-info-focus-color - Info context focus text color, default: #fff
 * @cssproperty --badge-link-info-focus-bg-color - Info context focus background color, default: #117a8b
 * @cssproperty --badge-link-info-link-outline - Info context link outline, default: 0
 * @cssproperty --badge-link-info-link-box-shadow - Info context link box shadow, default: 0 0 0 0.2rem rgba(23, 162, 184, 0.5)
 * @cssproperty --badge-link-warning-color - Warning context text color, default: #212529
 * @cssproperty --badge-link-warning-bg-color - Warning context background color, default: #ffc107
 * @cssproperty --badge-link-warning-text-decoration - Warning context text decoration, default: none
 * @cssproperty --badge-link-warning-hover-color - Warning context hover text color, default: #212529
 * @cssproperty --badge-link-warning-hover-bg-color - Warning context hover background color, default: #d39e00
 * @cssproperty --badge-link-warning-focus-color - Warning context focus text color, default: #212529
 * @cssproperty --badge-link-warning-focus-bg-color - Warning context focus background color, default: #d39e00
 * @cssproperty --badge-link-warning-link-outline - Warning context link outline, default: 0
 * @cssproperty --badge-link-warning-link-box-shadow - Warning context link box shadow, default: 0 0 0 0.2rem rgba(255, 193, 7, 0.5)
 * @cssproperty --badge-link-danger-color - Danger context text color, default: #fff
 * @cssproperty --badge-link-danger-bg-color - Danger context background color, default: #dc3545
 * @cssproperty --badge-link-danger-text-decoration - Danger context text decoration, default: none
 * @cssproperty --badge-link-danger-hover-color - Danger context hover text color, default: #fff
 * @cssproperty --badge-link-danger-hover-bg-color - Danger context hover background color, default: #bd2130
 * @cssproperty --badge-link-danger-focus-color - Danger context focus text color, default: #fff
 * @cssproperty --badge-link-danger-focus-bg-color - Danger context focus background color, default: #bd2130
 * @cssproperty --badge-link-danger-link-outline - Danger context link outline, default: 0
 * @cssproperty --badge-link-danger-link-box-shadow - Danger context link box shadow, default: 0 0 0 0.2rem rgba(220, 53, 69, 0.5)
 * @cssproperty --badge-link-light-color - Light context text color, default: #212529
 * @cssproperty --badge-link-light-bg-color - Light context background color, default: #f8f9fa
 * @cssproperty --badge-link-light-text-decoration - Light context text decoration, default: none
 * @cssproperty --badge-link-light-hover-color - Light context hover text color, default: #212529
 * @cssproperty --badge-link-light-hover-bg-color - Light context hover background color, default: #dae0e5
 * @cssproperty --badge-link-light-focus-color - Light context focus text color, default: #212529
 * @cssproperty --badge-link-light-focus-bg-color - Light context focus background color, default: #dae0e5
 * @cssproperty --badge-link-light-link-outline - Light context link outline, default: 0
 * @cssproperty --badge-link-light-link-box-shadow - Light context link box shadow, default: 0 0 0 0.2rem rgba(248, 249, 250, 0.5)
 * @cssproperty --badge-link-dark-color - Dark context text color, default: #fff
 * @cssproperty --badge-link-dark-bg-color - Dark context background color, default: #f8f9fa
 * @cssproperty --badge-link-dark-text-decoration - Dark context text decoration, default: none
 * @cssproperty --badge-link-dark-hover-color - Dark context hover text color, default: #fff
 * @cssproperty --badge-link-dark-hover-bg-color - Dark context hover background color, default: #1d2124
 * @cssproperty --badge-link-dark-focus-color - Dark context focus text color, default: #fff
 * @cssproperty --badge-link-dark-focus-bg-color - Dark context focus background color, default: #1d2124
 * @cssproperty --badge-link-dark-link-outline - Dark context link outline, default: 0
 * @cssproperty --badge-link-dark-link-box-shadow - Dark context link box shadow, default: 0 0 0 0.2rem rgba(52, 58, 64, 0.5)
 */

class BsBadgeLink extends LitElement {
  static get properties() {
    return {
      href: {
        type: String,
        reflect: true
      },
      target: {
        type: String,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsBadgeRebootCss, BsBadgeLinkCss];
  }

  render() {
    return html`
            <a href="${this.href}" .target="${this.target}">
                <slot></slot>
            </a>
        `;
  }

  constructor() {
    super();
    this.href = "";
    this.target = "_self";
  }

}
if (!window.customElements.get("bs-badge-link")) window.customElements.define("bs-badge-link", BsBadgeLink);

export { BsBadge, BsBadgeCss, BsBadgeLink, BsBadgeLinkCss };
//# sourceMappingURL=index.js.map
